@@ -1,15 +1,15 @@
 pub mod authority;
 pub mod config;
 pub mod daemon;
+pub mod fee;
 pub mod health;
-pub mod revenue;
 pub mod task;
 pub mod treasury;
 
 pub use authority::*;
 pub use config::*;
 pub use daemon::*;
+pub use fee::*;
 pub use health::*;
-pub use revenue::*;
 pub use task::*;
 pub use treasury::*;
